biosimulators_utils.kisao package — BioSimulators utils 0.1.154 documentation

# biosimulators_utils.kisao package

## Submodules

## biosimulators_utils.kisao.utils module

Utilities for working with KiSAO

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-05-27

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.kisao.utils.get_term(id)

  Get a KiSAO term

  Parameters

    id (`str`) – id

  Returns

    `pronto.Term`

biosimulators_utils.kisao.utils.get_term_type(term)

  Get the type of a KiSAO term (algorithm, algorithm characteristic, algorithm parameter)

  Parameters

    term (`pronto.Term`) – term

  Returns

    type of the term

  Return type

    `TermType`